import { Transform } from 'caterpillar'
/**
 * Convert Logger entries into human readable format.
 * @extends Transform
 * @example
 * ``` javascript
 * import Logger from 'caterpillar'
 * import Human from 'caterpillar-human'
 * const logger = new Logger()
 * const human = new Human()
 * logger.pipe(human).pipe(process.stdout)
 * logger.log('info', 'some', {data: 'oh yeah'}, 42)
 * ```
 */
declare class Human extends Transform {
	/** Get the initial configuration. */
	getInitialConfig(): {
		color: boolean
		level: null
		colors: {
			0: string
			1: string
			2: string
			3: string
			4: string
			5: string
			6: string
			7: string
		}
	}
	/** Get the color for the log level */
	getColor(levelNumber: number): string | false
	/** Pad the left of some content if need be with the specified padding to make the content reach a certain size */
	padLeft(padding: string, size: number, content: string | number): string
	/** Convert logger entry arguments into a human readable string */
	formatArguments(args: any[]): string
	/** Convert a datetime into a human readable format */
	formatDate(datetime: Date | number | string): string
	/** Convert a logger entry into a human readable format */
	format(message: string): string
}
export declare const create: typeof Transform.create
export default Human
//# sourceMappingURL=index.d.ts.map
